@@ -1,8 +1,8 @@
 # Created by shamilsakib at 04/10/20
 
 from django.contrib.contenttypes.models import ContentType
+from django.contrib.postgres.fields import JSONField
 from django.db import models
-from jsonfield import JSONField
 
 
 # BASE_MODEL = models.Model
@@ -12,11 +12,12 @@ from jsonfield import JSONField
 
 class ReportConfiguration(models.Model):
     model = models.ForeignKey(ContentType, default=None, null=True, on_delete=models.SET_NULL, related_name='reports')
-    report_config = JSONField(max_length=8192, default=None, null=True)
+    information = JSONField(max_length=8192, default=None, null=True)
     dimensions = JSONField(max_length=8192, default=None, null=True)
     measures = JSONField(max_length=8192, default=None, null=True)
     filters = JSONField(max_length=8192, default=None, null=True)
     searches = JSONField(max_length=8192, default=None, null=True)
+    report_config = JSONField(max_length=8192, default=None, null=True)
 
     def __init__(self, *args, **kwargs):
         super(ReportConfiguration, self).__init__(*args, **kwargs)
